pub struct Cli {
pub command: Commands,
}Fields
command: CommandsImplementations
Sourceimpl Cli
impl Cli
Sourcepub fn run(self) -> ExitCode
pub fn run(self) -> ExitCode
Run the CLI and return an exit code.
Errors are printed to stderr.
Sourcepub fn run_with_extensions(self, registry: ExtensionRegistry) -> ExitCode
pub fn run_with_extensions(self, registry: ExtensionRegistry) -> ExitCode
Run the CLI with a custom extension registry and return an exit code.
Use this when embedding the CLI in a binary that registers custom extension relation types:
ⓘ
let mut registry = ExtensionRegistry::new();
registry.register_relation::<MyCustomScan>().unwrap();
Cli::parse().run_with_extensions(registry)fn run_inner(self, registry: &ExtensionRegistry) -> Result<Outcome>
Sourcepub fn run_with_io<R: Read, W: Write>(
&self,
reader: R,
writer: W,
registry: &ExtensionRegistry,
) -> Result<Outcome>
pub fn run_with_io<R: Read, W: Write>( &self, reader: R, writer: W, registry: &ExtensionRegistry, ) -> Result<Outcome>
Run CLI with provided readers and writers for testing
fn create_output_options( &self, show_literal_types: bool, show_expression_types: bool, ) -> OutputOptions
fn resolve_input_format( &self, format: &Option<Format>, input_path: &str, ) -> Result<Format>
fn resolve_output_format( &self, format: &Option<Format>, output_path: &str, ) -> Result<Format>
fn run_convert_with_io<R: Read, W: Write>( &self, reader: R, writer: W, from: &Format, to: &Format, options: &OutputOptions, verbose: bool, registry: &ExtensionRegistry, ) -> Result<Outcome>
fn run_validate_with_io<R: Read, W: Write>( &self, reader: R, writer: W, verbose: bool, registry: &ExtensionRegistry, ) -> Result<Outcome>